/// <reference types="mongoose/types/aggregate" />
/// <reference types="mongoose/types/callback" />
/// <reference types="mongoose/types/collection" />
/// <reference types="mongoose/types/connection" />
/// <reference types="mongoose/types/cursor" />
/// <reference types="mongoose/types/document" />
/// <reference types="mongoose/types/error" />
/// <reference types="mongoose/types/expressions" />
/// <reference types="mongoose/types/helpers" />
/// <reference types="mongoose/types/middlewares" />
/// <reference types="mongoose/types/indexes" />
/// <reference types="mongoose/types/models" />
/// <reference types="mongoose/types/mongooseoptions" />
/// <reference types="mongoose/types/pipelinestage" />
/// <reference types="mongoose/types/populate" />
/// <reference types="mongoose/types/query" />
/// <reference types="mongoose/types/schemaoptions" />
/// <reference types="mongoose/types/schematypes" />
/// <reference types="mongoose/types/session" />
/// <reference types="mongoose/types/types" />
/// <reference types="mongoose/types/utility" />
/// <reference types="mongoose/types/validation" />
/// <reference types="mongoose/types/virtuals" />
/// <reference types="mongoose/types/inferschematype" />
import { QueryData, QueryResult } from '@jchpro/nest-common';
import type { Document, FilterQuery, Model, ProjectionType, Query, QueryOptions } from 'mongoose';
import { CrudOptions, FilterQueryProvider } from '../types/crud';
/**
 * Holds the query data for a given mongoose model and allows
 * execution of `count`, `find`, or both using `execute`.
 */
export declare class QueryExecutor<TDoc extends Document, TRaw = any> {
    readonly model: Model<TDoc>;
    readonly data: QueryData;
    readonly maxLimit?: number;
    readonly filters: FilterQuery<TRaw>;
    readonly queryOptions: QueryOptions<TDoc>;
    readonly projection?: ProjectionType<TRaw>;
    constructor(model: Model<TDoc>, data: QueryData, options?: {
        readonly filtersProvider?: FilterQueryProvider<TRaw>;
        readonly project?: ProjectionType<TRaw>;
        readonly crud?: CrudOptions;
        readonly other?: OtherQueryOptions;
    });
    execute(count?: Query<number, TDoc>, find?: Query<TDoc[], TDoc>): Promise<QueryResult<TDoc>>;
    count(): Query<number, TDoc>;
    find(): Query<TDoc[], TDoc>;
    private resolveQueryOptions;
}
export type OtherQueryOptions = Omit<QueryOptions, 'skip' | 'limit' | 'sort'>;
